==> elasticsearch-cambium-1.0.7.tgz: package/services/http.service.ts <==
const fetch = require("node-fetch");

export class HttpService {
  url: string;
  constructor(url: string = "http://localhost:9200") {
    this.url = url;
  }
  async deleteByElasticIp(index: string, id: string) {
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "DELETE",
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async addItem(index: string, obj: any, id: any = null) {
    if (id == null || id == undefined) {
        id=''
    }
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "POST",
      body: JSON.stringify(obj),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async updateItem(index: string, id: string, obj: any) {
    const body = {
      doc: obj,
      doc_as_upsert: true,
    };
    const x = await fetch(`${this.url}${index}/_update/${id}`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async deleteByField(index: string, field: string, value: string) {
    const body = {
      query: {
        match: {
          [field]: value,
        },
      },
    };
    const x = await fetch(`${this.url}${index}/_delete_by_query`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: "success" };
    } else {
      return { error: x };
    }
  }
  async getByElasticId(index: string, id: string) {
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "GET",
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res2: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return x;
    } else {
      return { error: x };
    }
  }
  async deleteByMultipleFields(index: string, query: any) {
    const body = {
      query: {
        bool: {
          must: query,
        },
      },
    };
    const x = await fetch(`${this.url}${index}/_delete_by_query`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: "success" };
    } else {
      return { error: x };
    }
  }
}

==> elasticsearch-cambium-1.0.9.tgz: package/services/http.service.ts <==
const fetch = require("node-fetch");

export class HttpService {
  url: string;
  constructor(url: string = "http://localhost:9200") {
    this.url = url;
  }
  async deleteByElasticIp(index: string, id: string) {
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "DELETE",
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async addItem(index: string, obj: any, id: any = null) {
    if (id == null || id == undefined) {
      id = "";
    }
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "POST",
      body: JSON.stringify(obj),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async searchByOneOfMultiFields(
    index: string,
    fields: Array<string>,
    txt: any = null
  ) {
    const body = {
      query: {
        multi_match: {
          query: txt,
          fields: fields,
        },
      },
    };
    const x = await fetch(`${this.url}${index}/_search`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["hits"] };
    } else {
      return { error: x };
    }
  }
  async updateItem(index: string, id: string, obj: any) {
    const body = {
      doc: obj,
      doc_as_upsert: true,
    };
    const x = await fetch(`${this.url}${index}/_update/${id}`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });

    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: x["result"] };
    } else {
      return { error: x };
    }
  }
  async deleteByField(index: string, field: string, value: string) {
    const body = {
      query: {
        match: {
          [field]: value,
        },
      },
    };
    const x = await fetch(`${this.url}${index}/_delete_by_query`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: "success" };
    } else {
      return { error: x };
    }
  }
  async getByElasticId(index: string, id: string) {
    const x = await fetch(`${this.url}${index}/_doc/${id}`, {
      method: "GET",
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res2: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return x;
    } else {
      return { error: x };
    }
  }
  async deleteByMultipleFields(index: string, query: any) {
    const body = {
      query: {
        bool: {
          must: query,
        },
      },
    };
    const x = await fetch(`${this.url}${index}/_delete_by_query`, {
      method: "POST",
      body: JSON.stringify(body),
      headers: { "Content-Type": "application/json" },
    }).then((res: any) => {
      if (!res.ok) {
        // console.log("res: ", res);
        return res.statusText;
      } else {
        return res.json();
      }
    });
    if (x !== "Not Found" && x !== "Bad Request") {
      return { result: "success" };
    } else {
      return { error: x };
    }
  }
}
